==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicSplitPaneUI__24KeyboardDownRightHandler.h <==
// public class javax.swing.plaf.basic.BasicSplitPaneUI$KeyboardDownRightHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2b878517099b1936 javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler_H_
#define _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$method$_init$985a59fb314729a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs {
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object {
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicSplitPaneUI__24KeyboardDownRightHandler.h <==
// public class javax.swing.plaf.basic.BasicSplitPaneUI$KeyboardDownRightHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2b878517099b1936 javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler_H_
#define _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$method$_init$985a59fb314729a2(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vmethods	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs {
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_refs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$object {
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$vtype _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicSplitPaneUI__24KeyboardDownRightHandler_H_ */
